@@ -27,5 +27,8 @@
 GtkWidget *dsn_config_new (void);
 void       dsn_config_edit_properties (GtkWidget *dsn);
 void       dsn_config_delete (GtkWidget *dsn);
+void       dsn_config_select_all (GtkWidget *dsn);
+void       dsn_config_unselect_all (GtkWidget *dsn);
+gboolean   dsn_config_has_selection (GtkWidget *dsn);
 
 #endif
