@@ -23,7 +23,8 @@
 #include <libgda/libgda.h>
 #include <glib/gi18n-lib.h>
 #include "gnome-db-data-cell-renderer-boolean.h"
-#include <libgnomedb/marshal.h>
+#include "marshal.h"
+#include <libgda/gda-enum-types.h>
 
 
 static void gnome_db_data_cell_renderer_boolean_get_property  (GObject *object,
@@ -36,6 +37,8 @@ static void gnome_db_data_cell_renderer_boolean_set_property  (GObject *object,
 							       GParamSpec *pspec);
 static void gnome_db_data_cell_renderer_boolean_init       (GnomeDbDataCellRendererBoolean      *celltext);
 static void gnome_db_data_cell_renderer_boolean_class_init (GnomeDbDataCellRendererBooleanClass *class);
+static void gnome_db_data_cell_renderer_boolean_dispose    (GObject *object);
+static void gnome_db_data_cell_renderer_boolean_finalize   (GObject *object);
 static void gnome_db_data_cell_renderer_boolean_render     (GtkCellRenderer            *cell,
 							    GdkWindow                  *window,
 							    GtkWidget                  *widget,
@@ -81,9 +84,12 @@ enum {
 	PROP_VALUE,
 	PROP_VALUE_ATTRIBUTES,
 	PROP_EDITABLE,
-	PROP_TO_BE_DELETED
+	PROP_TO_BE_DELETED,
+	PROP_DATA_HANDLER,
+	PROP_TYPE
 };
 
+static GObjectClass *parent_class = NULL;
 static guint toggle_cell_signals[LAST_SIGNAL] = { 0 };
 
 
@@ -131,6 +137,11 @@ gnome_db_data_cell_renderer_boolean_class_init (GnomeDbDataCellRendererBooleanCl
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
 	GtkCellRendererClass *cell_class = GTK_CELL_RENDERER_CLASS (class);
 
+	parent_class = g_type_class_peek_parent (class);
+
+	object_class->dispose = gnome_db_data_cell_renderer_boolean_dispose;
+	object_class->finalize = gnome_db_data_cell_renderer_boolean_finalize;
+
 	object_class->get_property = gnome_db_data_cell_renderer_boolean_get_property;
 	object_class->set_property = gnome_db_data_cell_renderer_boolean_set_property;
 
@@ -140,15 +151,16 @@ gnome_db_data_cell_renderer_boolean_class_init (GnomeDbDataCellRendererBooleanCl
   
 	g_object_class_install_property (object_class,
 					 PROP_VALUE,
-					 g_param_spec_pointer ("value",
+					 g_param_spec_boxed ("value",
                                                                _("Value"),
                                                                _("GValue to render"),
+                                                               G_TYPE_VALUE,
                                                                G_PARAM_READWRITE));
   
 	g_object_class_install_property (object_class,
 					 PROP_VALUE_ATTRIBUTES,
-					 g_param_spec_uint ("value_attributes", NULL, NULL,
-                                                            0, G_MAXUINT, 0, G_PARAM_READWRITE));
+					 g_param_spec_flags ("value_attributes", NULL, NULL, GDA_TYPE_VALUE_ATTRIBUTE,
+							     GDA_VALUE_ATTR_NONE, G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
 					 PROP_EDITABLE,
@@ -163,6 +175,15 @@ gnome_db_data_cell_renderer_boolean_class_init (GnomeDbDataCellRendererBooleanCl
 					 PROP_TO_BE_DELETED,
 					 g_param_spec_boolean ("to_be_deleted", NULL, NULL, FALSE,
                                                                G_PARAM_WRITABLE));
+	g_object_class_install_property(object_class,
+					 PROP_DATA_HANDLER,
+					 g_param_spec_object("data_handler", NULL, NULL, GDA_TYPE_DATA_HANDLER,
+							       G_PARAM_WRITABLE|G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property(object_class,
+					 PROP_TYPE,
+					 g_param_spec_gtype("type", NULL, NULL, G_TYPE_NONE,
+							       G_PARAM_WRITABLE|G_PARAM_CONSTRUCT_ONLY));
+  
 
 	toggle_cell_signals[CHANGED] =
 		g_signal_new ("changed",
@@ -170,10 +191,38 @@ gnome_db_data_cell_renderer_boolean_class_init (GnomeDbDataCellRendererBooleanCl
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GnomeDbDataCellRendererBooleanClass, changed),
 			      NULL, NULL,
-			      marshal_VOID__STRING_POINTER,
+			      gnome_db_marshal_VOID__STRING_BOXED,
 			      G_TYPE_NONE, 2,
 			      G_TYPE_STRING,
-			      G_TYPE_POINTER);
+			      G_TYPE_VALUE);
+}
+
+static void
+gnome_db_data_cell_renderer_boolean_dispose (GObject *object)
+{
+	GnomeDbDataCellRendererBoolean *datacell = GNOME_DB_DATA_CELL_RENDERER_BOOLEAN (object);
+
+	if (datacell->priv->dh) {
+		g_object_unref (G_OBJECT (datacell->priv->dh));
+		datacell->priv->dh = NULL;
+	}
+
+	/* parent class */
+	parent_class->dispose (object);
+}
+
+static void
+gnome_db_data_cell_renderer_boolean_finalize (GObject *object)
+{
+	GnomeDbDataCellRendererBoolean *datacell = GNOME_DB_DATA_CELL_RENDERER_BOOLEAN (object);
+
+	if (datacell->priv) {
+		g_free (datacell->priv);
+		datacell->priv = NULL;
+	}
+
+	/* parent class */
+	parent_class->finalize (object);
 }
 
 static void
@@ -186,7 +235,7 @@ gnome_db_data_cell_renderer_boolean_get_property (GObject *object,
   
 	switch (param_id) {
 	case PROP_VALUE:
-		g_value_set_pointer (value, cell->priv->value);
+		g_value_set_boxed (value, cell->priv->value);
 		break;
 	case PROP_VALUE_ATTRIBUTES:
 		break;
@@ -213,7 +262,7 @@ gnome_db_data_cell_renderer_boolean_set_property (GObject *object,
 		/* Because we don't have a copy of the value, we MUST NOT free it! */
                 cell->priv->value = NULL;
 		if (value) {			
-                        GValue *gval = g_value_get_pointer (value);
+                        GValue *gval = g_value_get_boxed (value);
 			if (gval && !gda_value_is_null (gval)) {
 				g_return_if_fail (G_VALUE_TYPE (gval) == cell->priv->type);
 				if (! gda_value_isa (gval, G_TYPE_BOOLEAN))
@@ -247,6 +296,17 @@ gnome_db_data_cell_renderer_boolean_set_property (GObject *object,
 	case PROP_TO_BE_DELETED:
 		cell->priv->to_be_deleted = g_value_get_boolean (value);
 		break;
+	case PROP_DATA_HANDLER:
+		if(cell->priv->dh)
+			g_object_unref (G_OBJECT(cell->priv->dh));
+
+		cell->priv->dh = GDA_DATA_HANDLER(g_value_get_object(value));
+		if(cell->priv->dh)
+			g_object_ref (G_OBJECT (cell->priv->dh));
+		break;
+	case PROP_TYPE:
+		cell->priv->type = g_value_get_gtype(value);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -275,13 +335,9 @@ gnome_db_data_cell_renderer_boolean_new (GdaDataHandler *dh, GType type)
         GnomeDbDataCellRendererBoolean *cell;
 
         g_return_val_if_fail (dh && GDA_IS_DATA_HANDLER (dh), NULL);
-        obj = g_object_new (GNOME_DB_TYPE_DATA_CELL_RENDERER_BOOLEAN, NULL);
-	
-        cell = GNOME_DB_DATA_CELL_RENDERER_BOOLEAN (obj);
-        cell->priv->dh = dh;
-        g_object_ref (G_OBJECT (dh));
-        cell->priv->type = type;
-	
+        obj = g_object_new (GNOME_DB_TYPE_DATA_CELL_RENDERER_BOOLEAN, "type", type, 
+                            "data_handler", dh, NULL);
+        	
         return GTK_CELL_RENDERER (obj);
 }
 
