@@ -51,7 +51,7 @@ static void            gnome_db_entry_combo_set_value_orig    (GnomeDbDataEntry
 static const GValue   *gnome_db_entry_combo_get_value_orig    (GnomeDbDataEntry *de);
 static void            gnome_db_entry_combo_set_value_default (GnomeDbDataEntry *de, const GValue * value);
 static void            gnome_db_entry_combo_set_attributes    (GnomeDbDataEntry *de, guint attrs, guint mask);
-static guint           gnome_db_entry_combo_get_attributes    (GnomeDbDataEntry *de);
+static GdaValueAttribute gnome_db_entry_combo_get_attributes    (GnomeDbDataEntry *de);
 static gboolean        gnome_db_entry_combo_expand_in_layout  (GnomeDbDataEntry *de);
 static void            gnome_db_entry_combo_grab_focus        (GnomeDbDataEntry *de);
 
@@ -99,7 +99,7 @@ gnome_db_entry_combo_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type) {
+	if (G_UNLIKELY (type == 0)) {
 		static const GTypeInfo info = {
 			sizeof (GnomeDbEntryComboClass),
 			(GBaseInitFunc) NULL,
@@ -236,23 +236,41 @@ GtkWidget *
 gnome_db_entry_combo_new (GdaParameterList *paramlist, GdaParameterListSource *source)
 {
 	GObject *obj;
-	GnomeDbEntryCombo *combo;
+
+	obj = g_object_new (GNOME_DB_TYPE_ENTRY_COMBO, NULL);
+  
+  _gnome_db_entry_combo_construct(GNOME_DB_ENTRY_COMBO (obj), paramlist, source);
+
+	return GTK_WIDGET (obj);
+}
+
+/**
+ * _gnome_db_entry_combo_construct
+ * @combo: a #GnomeDbEntryCombo object to be construced
+ * @paramlist: a #GdaParameterList object
+ * @source: a #GdaParameterListSource structure, part of @paramlist
+ *
+ * 
+ * TODO: This is just a work-around for language bindings. Ideally we would use construction
+ * properties instead.
+*/
+
+void _gnome_db_entry_combo_construct(GnomeDbEntryCombo* combo, 
+                                     GdaParameterList *paramlist, GdaParameterListSource *source)
+{
 	GSList *list;
 	GSList *values;
 	GtkWidget *entry;
 	gboolean null_possible;
 
-	g_return_val_if_fail (GDA_IS_PARAMETER_LIST (paramlist), NULL);
-	g_return_val_if_fail (source, NULL);
-	g_return_val_if_fail (g_slist_find (paramlist->sources_list, source), NULL);
-
-	obj = g_object_new (GNOME_DB_TYPE_ENTRY_COMBO, NULL);
-	combo = GNOME_DB_ENTRY_COMBO (obj);
-
-	combo->priv->paramlist = paramlist;
+	g_return_if_fail (GDA_IS_PARAMETER_LIST (paramlist));
+	g_return_if_fail (source);
+	g_return_if_fail (g_slist_find (paramlist->sources_list, source));
+  
+  combo->priv->paramlist = paramlist;
 	combo->priv->source = source;
 	gda_object_connect_destroy (GDA_OBJECT (paramlist), 
-				    G_CALLBACK (paramlist_destroyed_cb), obj);	
+				    G_CALLBACK (paramlist_destroyed_cb), G_OBJECT(combo));	
 
 	/* create the ComboNode structures, 
 	 * and use the values provided by the parameters to display the correct row */
@@ -288,8 +306,6 @@ gnome_db_entry_combo_new (GdaParameterList *paramlist, GdaParameterListSource *s
 	gnome_db_combo_set_values_ext (GNOME_DB_COMBO (entry), values, NULL);
 	g_slist_free (values);
 	gnome_db_combo_add_undef_choice (GNOME_DB_COMBO (entry), combo->priv->null_possible);
-
-	return GTK_WIDGET (obj);
 }
 
 static void
@@ -909,10 +925,10 @@ gnome_db_entry_combo_set_attributes (GnomeDbDataEntry *iface, guint attrs, guint
 	g_signal_emit_by_name (G_OBJECT (combo), "status_changed");
 }
 
-static guint
+static GdaValueAttribute
 gnome_db_entry_combo_get_attributes (GnomeDbDataEntry *iface)
 {
-	guint retval = 0;
+	GdaValueAttribute retval = 0;
 	GnomeDbEntryCombo *combo;
 	GSList *list;
 	GSList *list2;
