@@ -52,7 +52,7 @@ struct _GnomeDbEntryComboClass
 };
 
 
-GType           gnome_db_entry_combo_get_type          (void);
+GType           gnome_db_entry_combo_get_type          (void) G_GNUC_CONST;
 GtkWidget      *gnome_db_entry_combo_new               (GdaParameterList *paramlist, GdaParameterListSource *source);
 
 gboolean        gnome_db_entry_combo_set_values        (GnomeDbEntryCombo *combo, GSList *values);
