@@ -1,6 +1,6 @@
 /* gnome-db-transaction-status.c
  *
- * Copyright (C) 2002 - 2006 Vivien Malerba
+ * Copyright (C) 2002 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -69,7 +69,7 @@ gnome_db_transaction_status_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type) {
+	if (G_UNLIKELY (type == 0)) {
 		static const GTypeInfo info = {
 			sizeof (GnomeDbTransactionStatusClass),
 			(GBaseInitFunc) NULL,
@@ -102,8 +102,8 @@ gnome_db_transaction_status_class_init (GnomeDbTransactionStatusClass * class)
         object_class->get_property = gnome_db_transaction_status_get_property;
 
 	g_object_class_install_property (object_class, PROP_CNC,
-                                         g_param_spec_pointer ("connection", 
-                                                               _("Used connection"), NULL,
+                                         g_param_spec_object ("connection", 
+                                                               _("Used connection"), NULL, GDA_TYPE_CONNECTION,
                                                                G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
@@ -181,13 +181,13 @@ gnome_db_transaction_status_set_property (GObject *object,
 					  GParamSpec *pspec)
 {
 	GnomeDbTransactionStatus *status;
-	GdaConnection *cnc;
+	GdaConnection *cnc = NULL;
 
         status = GNOME_DB_TRANSACTION_STATUS (object);
         if (status->priv) {
                 switch (param_id) {
 		case PROP_CNC:
-			cnc = g_value_get_pointer (value);
+			cnc = g_value_get_object (value);
 			if (status->priv->cnc) {
 				gnome_db_transaction_status_clean (status);
 				g_object_weak_unref (G_OBJECT (status->priv->cnc), (GWeakNotify) cnc_weak_ref_func, status);
@@ -225,7 +225,7 @@ gnome_db_transaction_status_get_property (GObject *object,
         if (status->priv) {
                 switch (param_id) {
 		case PROP_CNC:
-			g_value_set_pointer (value, status->priv->cnc);
+			g_value_set_object (value, status->priv->cnc);
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
@@ -289,8 +289,9 @@ create_widget_for_tstatus (GnomeDbTransactionStatus *status, GdaTransactionStatu
 	GList *list;
 	GtkTable *table;
 	gboolean has_sub_trans = FALSE;
+	gboolean trans_alive = (gdastatus->state == GDA_TRANSACTION_STATUS_STATE_OK) ? TRUE : FALSE;
 
-	table = (GtkTable*) gtk_table_new (g_list_length (gdastatus->events) + 1, 2, FALSE);
+	table = (GtkTable*) gtk_table_new (g_list_length (gdastatus->events) + 2, 2, FALSE);
 	
 	/* transaction label */
 	hbox = gtk_hbox_new (FALSE, 0);
@@ -308,14 +309,30 @@ create_widget_for_tstatus (GnomeDbTransactionStatus *status, GdaTransactionStatu
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show (label);
 
-	button = gtk_link_button_new_with_label ("commit", _("Commit"));
-	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
-	gtk_widget_show (button);
-	g_object_set_data (G_OBJECT (button), "_gnomedb_trans_status", status);
-	g_signal_connect (G_OBJECT (button), "clicked",
-			  G_CALLBACK (trans_commit_clicked_cb), gdastatus);
+	if (trans_alive) {
+                /* Allow this to build with both GTK+ 2.8 and GTK+ 2.10.
+                 * However, a GtkLinkButton is probably bad UI anyway.
+                 * The URI (e.g. "commit") does not seem to be used either)
+                 */
+                #if GTK_MINOR_VERSION >= 10
+		button = gtk_link_button_new_with_label ("commit", _("Commit"));
+                #else
+                button = gtk_button_new_with_label (_("Commit"));
+                #endif
 
+		gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+		gtk_widget_show (button);
+		g_object_set_data (G_OBJECT (button), "_gnomedb_trans_status", status);
+		g_signal_connect (G_OBJECT (button), "clicked",
+				  G_CALLBACK (trans_commit_clicked_cb), gdastatus);
+	}
+
+        #if GTK_MINOR_VERSION >= 10
 	button = gtk_link_button_new_with_label ("rollback", _("Rollback"));
+        #else
+        button = gtk_button_new_with_label (_("Rollback"));
+        #endif
+
 	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 	gtk_widget_show (button);
 	g_object_set_data (G_OBJECT (button), "_gnomedb_trans_status", status);
@@ -351,8 +368,14 @@ create_widget_for_tstatus (GnomeDbTransactionStatus *status, GdaTransactionStatu
 			gtk_widget_show (label);
 
 			if (gda_connection_supports_feature (status->priv->cnc, 
-							     GDA_CONNECTION_FEATURE_SAVEPOINTS)) {
-				button = gtk_link_button_new_with_label ("rollbacksvp", _("Rollback"));
+							     GDA_CONNECTION_FEATURE_SAVEPOINTS) &&
+			    trans_alive) {
+                                #if GTK_MINOR_VERSION >= 10
+	                        button = gtk_link_button_new_with_label ("rollbacksvp", _("Rollback"));
+                                #else
+                                button = gtk_button_new_with_label (_("Rollback"));
+                                #endif
+				
 				gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 				gtk_widget_show (button);
 				g_object_set_data (G_OBJECT (button), "_gnomedb_trans_status", status);
@@ -362,7 +385,12 @@ create_widget_for_tstatus (GnomeDbTransactionStatus *status, GdaTransactionStatu
 
 				if (gda_connection_supports_feature (status->priv->cnc, 
 								     GDA_CONNECTION_FEATURE_SAVEPOINTS_REMOVE)) {
+                                        #if GTK_MINOR_VERSION >= 10
 					button = gtk_link_button_new_with_label ("delsvp", _("Delete"));
+                                        #else
+                                        button = gtk_button_new_with_label (_("Delete"));
+                                        #endif
+
 					gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 					gtk_widget_show (button);
 					g_object_set_data (G_OBJECT (button), "_gnomedb_trans_status", status);
@@ -405,7 +433,8 @@ create_widget_for_tstatus (GnomeDbTransactionStatus *status, GdaTransactionStatu
 	/* Add savepoint button */
 	if (!has_sub_trans && status->priv->cnc && 
 	    gda_connection_supports_feature (status->priv->cnc, 
-					     GDA_CONNECTION_FEATURE_SAVEPOINTS)) {
+					     GDA_CONNECTION_FEATURE_SAVEPOINTS) &&
+	    trans_alive) {
 		hbox = gtk_hbox_new (FALSE, 0);
 		gtk_table_attach (table, hbox, 1, 2, evidx, evidx + 1, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 		gtk_widget_show (hbox);
@@ -414,12 +443,41 @@ create_widget_for_tstatus (GnomeDbTransactionStatus *status, GdaTransactionStatu
 		gtk_table_attach (table, pad, 0, 1, evidx, evidx + 1, 0, 0, 0, 0);
 		gtk_widget_show (pad);
 
+                #if GTK_MINOR_VERSION >= 10
 		button = gtk_link_button_new_with_label ("addsvp", _("Add save point"));
+                #else
+                button = gtk_button_new_with_label(_("Add save point"));
+                #endif
+
 		gtk_widget_show (button);
 		gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 		g_object_set_data (G_OBJECT (button), "_gnomedb_trans_status", status);
 		g_signal_connect (G_OBJECT (button), "clicked",
 				  G_CALLBACK (trans_savepoint_add_clicked_cb), gdastatus);
+		evidx++;
+	}
+
+	/* message about transaction state */
+	str = NULL;
+	switch (gdastatus->state) {
+	case GDA_TRANSACTION_STATUS_STATE_OK:
+		break;
+	case GDA_TRANSACTION_STATUS_STATE_FAILED:
+		str = _("Transaction locked (any further query will fail),\nroll back the transaction");
+		break;
+	default:
+		g_warning (_("Unknown transaction state %d, please report error"), gdastatus->state);
+	}
+	if (str) {
+		gchar *str2;
+
+		str2 = g_strdup_printf ("<span foreground=\"red\">%s</span>", str);
+		label = gtk_label_new (str2);
+		g_free (str2);
+		gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+		gtk_misc_set_alignment (GTK_MISC (label), 0., 0.5);
+		gtk_table_attach (table, label, 0, 2, evidx, evidx + 1, 0, GTK_FILL, 0, 0);
+		gtk_widget_show (label);
 	}
 
 	return (GtkWidget *) table;
@@ -482,7 +540,12 @@ gnome_db_transaction_status_refresh (GnomeDbTransactionStatus *status)
 						     GDA_CONNECTION_FEATURE_TRANSACTIONS)) {
 			GtkWidget *button;
 
-			button = gtk_link_button_new_with_label ("begin", _("Begin transaction"));
+                        #if GTK_MINOR_VERSION >= 10
+		        button = gtk_link_button_new_with_label ("begin", _("Begin transaction"));
+                        #else
+                        button = gtk_button_new_with_label(_("Begin transaction"));
+                        #endif
+
 			gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 			gtk_widget_show (button);
 			g_signal_connect (G_OBJECT (button), "clicked",
