@@ -51,12 +51,12 @@
 
 /* VOID:VOID,VOID (marshal.list:28) */
 void
-marshal_VOID__VOID_VOID (GClosure     *closure,
-                         GValue       *return_value,
-                         guint         n_param_values,
-                         const GValue *param_values,
-                         gpointer      invocation_hint,
-                         gpointer      marshal_data)
+gnome_db_marshal_VOID__VOID_VOID (GClosure     *closure,
+                                  GValue       *return_value,
+                                  guint         n_param_values,
+                                  const GValue *param_values,
+                                  gpointer      invocation_hint,
+                                  gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__VOID_VOID) (gpointer     data1,
                                                 gpointer     data2);
@@ -86,12 +86,12 @@ marshal_VOID__VOID_VOID (GClosure     *closure,
 
 /* VOID:POINTER,POINTER (marshal.list:30) */
 void
-marshal_VOID__POINTER_POINTER (GClosure     *closure,
-                               GValue       *return_value,
-                               guint         n_param_values,
-                               const GValue *param_values,
-                               gpointer      invocation_hint,
-                               gpointer      marshal_data)
+gnome_db_marshal_VOID__POINTER_POINTER (GClosure     *closure,
+                                        GValue       *return_value,
+                                        guint         n_param_values,
+                                        const GValue *param_values,
+                                        gpointer      invocation_hint,
+                                        gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__POINTER_POINTER) (gpointer     data1,
                                                       gpointer     arg_1,
@@ -123,12 +123,12 @@ marshal_VOID__POINTER_POINTER (GClosure     *closure,
 
 /* VOID:POINTER,UINT,UINT (marshal.list:31) */
 void
-marshal_VOID__POINTER_UINT_UINT (GClosure     *closure,
-                                 GValue       *return_value,
-                                 guint         n_param_values,
-                                 const GValue *param_values,
-                                 gpointer      invocation_hint,
-                                 gpointer      marshal_data)
+gnome_db_marshal_VOID__POINTER_UINT_UINT (GClosure     *closure,
+                                          GValue       *return_value,
+                                          guint         n_param_values,
+                                          const GValue *param_values,
+                                          gpointer      invocation_hint,
+                                          gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__POINTER_UINT_UINT) (gpointer     data1,
                                                         gpointer     arg_1,
@@ -168,12 +168,12 @@ marshal_VOID__POINTER_UINT_UINT (GClosure     *closure,
 
 /* VOID:OBJECT,BOOL (marshal.list:35) */
 void
-marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
-                              GValue       *return_value,
-                              guint         n_param_values,
-                              const GValue *param_values,
-                              gpointer      invocation_hint,
-                              gpointer      marshal_data)
+gnome_db_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
+                                       GValue       *return_value,
+                                       guint         n_param_values,
+                                       const GValue *param_values,
+                                       gpointer      invocation_hint,
+                                       gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__OBJECT_BOOLEAN) (gpointer     data1,
                                                      gpointer     arg_1,
@@ -207,12 +207,12 @@ marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
 
 /* VOID:STRING,STRING (marshal.list:37) */
 void
-marshal_VOID__STRING_STRING (GClosure     *closure,
-                             GValue       *return_value,
-                             guint         n_param_values,
-                             const GValue *param_values,
-                             gpointer      invocation_hint,
-                             gpointer      marshal_data)
+gnome_db_marshal_VOID__STRING_STRING (GClosure     *closure,
+                                      GValue       *return_value,
+                                      guint         n_param_values,
+                                      const GValue *param_values,
+                                      gpointer      invocation_hint,
+                                      gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_STRING) (gpointer     data1,
                                                     gpointer     arg_1,
@@ -244,12 +244,12 @@ marshal_VOID__STRING_STRING (GClosure     *closure,
 
 /* VOID:STRING,BOXED (marshal.list:38) */
 void
-marshal_VOID__STRING_BOXED (GClosure     *closure,
-                            GValue       *return_value,
-                            guint         n_param_values,
-                            const GValue *param_values,
-                            gpointer      invocation_hint,
-                            gpointer      marshal_data)
+gnome_db_marshal_VOID__STRING_BOXED (GClosure     *closure,
+                                     GValue       *return_value,
+                                     guint         n_param_values,
+                                     const GValue *param_values,
+                                     gpointer      invocation_hint,
+                                     gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_BOXED) (gpointer     data1,
                                                    gpointer     arg_1,
@@ -281,12 +281,12 @@ marshal_VOID__STRING_BOXED (GClosure     *closure,
 
 /* VOID:STRING,POINTER,POINTER (marshal.list:39) */
 void
-marshal_VOID__STRING_POINTER_POINTER (GClosure     *closure,
-                                      GValue       *return_value,
-                                      guint         n_param_values,
-                                      const GValue *param_values,
-                                      gpointer      invocation_hint,
-                                      gpointer      marshal_data)
+gnome_db_marshal_VOID__STRING_POINTER_POINTER (GClosure     *closure,
+                                               GValue       *return_value,
+                                               guint         n_param_values,
+                                               const GValue *param_values,
+                                               gpointer      invocation_hint,
+                                               gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_POINTER_POINTER) (gpointer     data1,
                                                              gpointer     arg_1,
@@ -320,12 +320,12 @@ marshal_VOID__STRING_POINTER_POINTER (GClosure     *closure,
 
 /* VOID:STRING,ENUM (marshal.list:40) */
 void
-marshal_VOID__STRING_ENUM (GClosure     *closure,
-                           GValue       *return_value,
-                           guint         n_param_values,
-                           const GValue *param_values,
-                           gpointer      invocation_hint,
-                           gpointer      marshal_data)
+gnome_db_marshal_VOID__STRING_ENUM (GClosure     *closure,
+                                    GValue       *return_value,
+                                    guint         n_param_values,
+                                    const GValue *param_values,
+                                    gpointer      invocation_hint,
+                                    gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_ENUM) (gpointer     data1,
                                                   gpointer     arg_1,
@@ -359,12 +359,12 @@ marshal_VOID__STRING_ENUM (GClosure     *closure,
 
 /* STRING:STRING (marshal.list:42) */
 void
-marshal_STRING__STRING (GClosure     *closure,
-                        GValue       *return_value,
-                        guint         n_param_values,
-                        const GValue *param_values,
-                        gpointer      invocation_hint,
-                        gpointer      marshal_data)
+gnome_db_marshal_STRING__STRING (GClosure     *closure,
+                                 GValue       *return_value,
+                                 guint         n_param_values,
+                                 const GValue *param_values,
+                                 gpointer      invocation_hint,
+                                 gpointer      marshal_data)
 {
   typedef gchar* (*GMarshalFunc_STRING__STRING) (gpointer     data1,
                                                  gpointer     arg_1,
@@ -396,16 +396,55 @@ marshal_STRING__STRING (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
-/* VOID:POINTER,POINTER (marshal.list:45) */
-
-/* VOID:STRING,POINTER (marshal.list:46) */
+/* BOOLEAN:POINTER (marshal.list:43) */
 void
-marshal_VOID__STRING_POINTER (GClosure     *closure,
-                              GValue       *return_value,
-                              guint         n_param_values,
-                              const GValue *param_values,
-                              gpointer      invocation_hint,
-                              gpointer      marshal_data)
+gnome_db_marshal_BOOLEAN__POINTER (GClosure     *closure,
+                                   GValue       *return_value,
+                                   guint         n_param_values,
+                                   const GValue *param_values,
+                                   gpointer      invocation_hint,
+                                   gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__POINTER) (gpointer     data1,
+                                                     gpointer     arg_1,
+                                                     gpointer     data2);
+  register GMarshalFunc_BOOLEAN__POINTER callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 2);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__POINTER) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_pointer (param_values + 1),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* VOID:POINTER,POINTER (marshal.list:46) */
+
+/* VOID:STRING,POINTER (marshal.list:47) */
+void
+gnome_db_marshal_VOID__STRING_POINTER (GClosure     *closure,
+                                       GValue       *return_value,
+                                       guint         n_param_values,
+                                       const GValue *param_values,
+                                       gpointer      invocation_hint,
+                                       gpointer      marshal_data)
 {
   typedef void (*GMarshalFunc_VOID__STRING_POINTER) (gpointer     data1,
                                                      gpointer     arg_1,
